@@ -4,11 +4,15 @@ See the docs at https://github.com/esheldon/fitsio for example
 usage.
 """
 
-__version__='0.9.5'
+__version__='0.9.6'
 
 from . import fitslib
+
 from .fitslib import FITS
 from .fitslib import FITSHDR
+from .fitslib import FITSRecord
+from .fitslib import FITSCard
+
 from .fitslib import read
 from .fitslib import read_header
 from .fitslib import write
